==> sawfish-1.3.3_2%2C2.tbz: share/sawfish/1.3.3/lisp/sawfish/wm/cursors.jl <==
#| sawfish.wm.cursors bootstrap

   $Id: cursors.jl,v 1.3 2000/07/27 13:19:29 john Exp $

   Copyright (C) 1999 John Harper <john@dcs.warwick.ac.uk>

   This file is part of sawmill.

   sawmill is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2, or (at your option)
   any later version.

   sawmill is distributed in the hope that it will be useful, but
   WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with sawmill; see the file COPYING.  If not, write to
   the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
|#

(declare (in-module sawfish.wm.cursors))

(open-structures '(rep))

(put 'X_cursor 'cursor-shape 0)
(put 'arrow 'cursor-shape 2)
(put 'based_arrow_down 'cursor-shape 4)
(put 'based_arrow_up 'cursor-shape 6)
(put 'boat 'cursor-shape 8)
(put 'bogosity 'cursor-shape 10)
(put 'bottom_left_corner 'cursor-shape 12)
(put 'bottom_right_corner 'cursor-shape 14)
(put 'bottom_side 'cursor-shape 16)
(put 'bottom_tee 'cursor-shape 18)
(put 'box_spiral 'cursor-shape 20)
(put 'center_ptr 'cursor-shape 22)
(put 'circle 'cursor-shape 24)
(put 'clock 'cursor-shape 26)
(put 'coffee_mug 'cursor-shape 28)
(put 'cross 'cursor-shape 30)
(put 'cross_reverse 'cursor-shape 32)
(put 'crosshair 'cursor-shape 34)
(put 'diamond_cross 'cursor-shape 36)
(put 'dot 'cursor-shape 38)
(put 'dotbox 'cursor-shape 40)
(put 'double_arrow 'cursor-shape 42)
(put 'draft_large 'cursor-shape 44)
(put 'draft_small 'cursor-shape 46)
(put 'draped_box 'cursor-shape 48)
(put 'exchange 'cursor-shape 50)
(put 'fleur 'cursor-shape 52)
(put 'gobbler 'cursor-shape 54)
(put 'gumby 'cursor-shape 56)
(put 'hand1 'cursor-shape 58)
(put 'hand2 'cursor-shape 60)
(put 'heart 'cursor-shape 62)
(put 'icon 'cursor-shape 64)
(put 'iron_cross 'cursor-shape 66)
(put 'left_ptr 'cursor-shape 68)
(put 'left_side 'cursor-shape 70)
(put 'left_tee 'cursor-shape 72)
(put 'leftbutton 'cursor-shape 74)
(put 'll_angle 'cursor-shape 76)
(put 'lr_angle 'cursor-shape 78)
(put 'man 'cursor-shape 80)
(put 'middlebutton 'cursor-shape 82)
(put 'mouse 'cursor-shape 84)
(put 'pencil 'cursor-shape 86)
(put 'pirate 'cursor-shape 88)
(put 'plus 'cursor-shape 90)
(put 'question_arrow 'cursor-shape 92)
(put 'right_ptr 'cursor-shape 94)
(put 'right_side 'cursor-shape 96)
(put 'right_tee 'cursor-shape 98)
(put 'rightbutton 'cursor-shape 100)
(put 'rtl_logo 'cursor-shape 102)
(put 'sailboat 'cursor-shape 104)
(put 'sb_down_arrow 'cursor-shape 106)
(put 'sb_h_double_arrow 'cursor-shape 108)
(put 'sb_left_arrow 'cursor-shape 110)
(put 'sb_right_arrow 'cursor-shape 112)
(put 'sb_up_arrow 'cursor-shape 114)
(put 'sb_v_double_arrow 'cursor-shape 116)
(put 'shuttle 'cursor-shape 118)
(put 'sizing 'cursor-shape 120)
(put 'spider 'cursor-shape 122)
(put 'spraycan 'cursor-shape 124)
(put 'star 'cursor-shape 126)
(put 'target 'cursor-shape 128)
(put 'tcross 'cursor-shape 130)
(put 'top_left_arrow 'cursor-shape 132)
(put 'top_left_corner 'cursor-shape 134)
(put 'top_right_corner 'cursor-shape 136)
(put 'top_side 'cursor-shape 138)
(put 'top_tee 'cursor-shape 140)
(put 'trek 'cursor-shape 142)
(put 'ul_angle 'cursor-shape 144)
(put 'umbrella 'cursor-shape 146)
(put 'ur_angle 'cursor-shape 148)
(put 'watch 'cursor-shape 150)
(put 'xterm 'cursor-shape 152)

==> sawfish-1.5.2_2%2C2.tbz: share/sawfish/1.5.2/lisp/sawfish/wm/cursors.jl <==
#| sawfish.wm.cursors bootstrap

   $Id: cursors.jl,v 1.3 2000/07/27 13:19:29 john Exp $

   Copyright (C) 1999 John Harper <john@dcs.warwick.ac.uk>

   This file is part of sawfish.

   sawfish is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2, or (at your option)
   any later version.

   sawfish is distributed in the hope that it will be useful, but
   WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with sawfish; see the file COPYING.  If not, write to
   the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
|#

(declare (in-module sawfish.wm.cursors))

(open-structures '(rep))

(put 'X_cursor 'cursor-shape 0)
(put 'arrow 'cursor-shape 2)
(put 'based_arrow_down 'cursor-shape 4)
(put 'based_arrow_up 'cursor-shape 6)
(put 'boat 'cursor-shape 8)
(put 'bogosity 'cursor-shape 10)
(put 'bottom_left_corner 'cursor-shape 12)
(put 'bottom_right_corner 'cursor-shape 14)
(put 'bottom_side 'cursor-shape 16)
(put 'bottom_tee 'cursor-shape 18)
(put 'box_spiral 'cursor-shape 20)
(put 'center_ptr 'cursor-shape 22)
(put 'circle 'cursor-shape 24)
(put 'clock 'cursor-shape 26)
(put 'coffee_mug 'cursor-shape 28)
(put 'cross 'cursor-shape 30)
(put 'cross_reverse 'cursor-shape 32)
(put 'crosshair 'cursor-shape 34)
(put 'diamond_cross 'cursor-shape 36)
(put 'dot 'cursor-shape 38)
(put 'dotbox 'cursor-shape 40)
(put 'double_arrow 'cursor-shape 42)
(put 'draft_large 'cursor-shape 44)
(put 'draft_small 'cursor-shape 46)
(put 'draped_box 'cursor-shape 48)
(put 'exchange 'cursor-shape 50)
(put 'fleur 'cursor-shape 52)
(put 'gobbler 'cursor-shape 54)
(put 'gumby 'cursor-shape 56)
(put 'hand1 'cursor-shape 58)
(put 'hand2 'cursor-shape 60)
(put 'heart 'cursor-shape 62)
(put 'icon 'cursor-shape 64)
(put 'iron_cross 'cursor-shape 66)
(put 'left_ptr 'cursor-shape 68)
(put 'left_side 'cursor-shape 70)
(put 'left_tee 'cursor-shape 72)
(put 'leftbutton 'cursor-shape 74)
(put 'll_angle 'cursor-shape 76)
(put 'lr_angle 'cursor-shape 78)
(put 'man 'cursor-shape 80)
(put 'middlebutton 'cursor-shape 82)
(put 'mouse 'cursor-shape 84)
(put 'pencil 'cursor-shape 86)
(put 'pirate 'cursor-shape 88)
(put 'plus 'cursor-shape 90)
(put 'question_arrow 'cursor-shape 92)
(put 'right_ptr 'cursor-shape 94)
(put 'right_side 'cursor-shape 96)
(put 'right_tee 'cursor-shape 98)
(put 'rightbutton 'cursor-shape 100)
(put 'rtl_logo 'cursor-shape 102)
(put 'sailboat 'cursor-shape 104)
(put 'sb_down_arrow 'cursor-shape 106)
(put 'sb_h_double_arrow 'cursor-shape 108)
(put 'sb_left_arrow 'cursor-shape 110)
(put 'sb_right_arrow 'cursor-shape 112)
(put 'sb_up_arrow 'cursor-shape 114)
(put 'sb_v_double_arrow 'cursor-shape 116)
(put 'shuttle 'cursor-shape 118)
(put 'sizing 'cursor-shape 120)
(put 'spider 'cursor-shape 122)
(put 'spraycan 'cursor-shape 124)
(put 'star 'cursor-shape 126)
(put 'target 'cursor-shape 128)
(put 'tcross 'cursor-shape 130)
(put 'top_left_arrow 'cursor-shape 132)
(put 'top_left_corner 'cursor-shape 134)
(put 'top_right_corner 'cursor-shape 136)
(put 'top_side 'cursor-shape 138)
(put 'top_tee 'cursor-shape 140)
(put 'trek 'cursor-shape 142)
(put 'ul_angle 'cursor-shape 144)
(put 'umbrella 'cursor-shape 146)
(put 'ur_angle 'cursor-shape 148)
(put 'watch 'cursor-shape 150)
(put 'xterm 'cursor-shape 152)
